@@ -88,6 +88,9 @@ class Terminal(object):
     def cursor(self, flag):
         if self.curses:
             param = "cnorm" if flag else "civis"
-            sys.stdout.write(self.curses.tigetstr(param))
-            sys.stdout.flush()
+            try:
+                sys.stdout.write(self.curses.tigetstr(param))
+                sys.stdout.flush()
+            except TypeError:
+                pass
             self.__cursor = flag
