@@ -651,7 +651,7 @@ def check_rw(dn):
     while mark_file is None or path.exists(mark_file):
         mark_file = path.join(dn, "_mark_%s" % _random_string())
     try:
-        open(mark_file, 'w')
+        open(mark_file, 'w').close()
         os.unlink(mark_file)
         return True
     except (OSError, IOError):
@@ -686,44 +686,6 @@ def removeFileWithEmptyDirectory(rmName, stopDirectory="/"):
                                          stopDirectory=stopDirectory)
 
 
-def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False):
-    """List run program"""
-
-    def getCmd(procNum):
-        cmdLineFile = '/proc/%s/cmdline' % procNum
-        try:
-            if uid is not None:
-                fstat = os.stat("/proc/%s"%procNum)
-                if fstat.st_uid != uid:
-                    return ""
-            if path.exists(cmdLineFile):
-                if not_chroot:
-                    root_link = '/proc/%s/root' % procNum
-                    if os.readlink(root_link) != "/":
-                        return ""
-                if chroot is not None:
-                    root_link = '/proc/%s/root' % procNum
-                    if os.readlink(root_link) != chroot:
-                        return ""
-                return open(cmdLineFile, 'r').read().strip()
-        except Exception:
-            pass
-        return ""
-
-    if not os.access('/proc', os.R_OK):
-        return []
-    if withpid:
-        return filter(lambda x: x[1],
-                      map(lambda x:(x,getCmd(x)),
-                          filter(lambda x: x.isdigit(),
-                                 listDirectory('/proc'))))
-    else:
-        return filter(None,
-                      map(getCmd,
-                          filter(lambda x: x.isdigit(),
-                                 listDirectory('/proc'))))
-
-
 def pathJoin(*paths):
     """Складывает пути, в отличии от os.path.join, складывает абсолютные пути"""
     if len(paths) == 1:
@@ -734,22 +696,6 @@ def pathJoin(*paths):
                              paths[1:])), paths[0])
 
 
-def checkDigestFile(digestfile):
-    """Check digest by digestfile"""
-    reEntry = re.compile(r"# (\S+) HASH\n(\S+)  (\S+)", re.S)
-    result = []
-    for alg, hashdata, filename in reEntry.findall(
-            open(digestfile, 'r').read()):
-        if hasattr(hashlib, alg.lower()):
-            hashobj = getattr(hashlib, alg.lower())
-            filename = path.join(path.dirname(digestfile), filename)
-            if os.path.exists(filename):
-                digest = hashobj(open(filename, 'r').read())
-                result.append((alg,
-                               digest.hexdigest().upper() == hashdata.upper()))
-    return result
-
-
 def listDirectory(directory, fullPath=False, onlyDir=False):
     """Get files from directory, if it exists"""
     if not path.exists(directory):
@@ -827,24 +773,37 @@ def grepFile(filename, regexp, flags=0):
         return match.group()
     return ""
 
+def readFile(filename):
+    """
+    Прочитать целый файл или вернуть пустую строку в случае ошибки
+    """
+    try:
+        if path.exists(filename):
+            with open(filename, 'r') as f:
+                return f.read()
+    except (OSError, IOError) as e:
+        mod, lno = tools.get_traceback_caller(*sys.exc_info())
+        sys.stderr.write("WARNING: file read error, {}({}:{})\n".format(
+            str(e), mod, lno))
+        sys.stderr.flush()
+    return ""
 
-def readFile(filename, tailbyte=None, headbyte=None, grab=False):
+def readFileEx(filename, tailbyte=None, headbyte=None, grab=False):
     """
     Прочитать целый файл или вернуть пустую строку.
     tailbyte: прочитать только последнее указанное количество байт
     headbyte: прочитать только первое указанное количество байт
     grab: отбросить пустые строки и комментарии (#)
     """
-    def grabdata(s):
-        return "\n".join(x for x in s.split("\n")
-                         if not x.startswith("#") and x.strip())
-    if grab:
-        filterfunc = grabdata
-    else:
-        filterfunc = lambda x: x
     try:
         if path.exists(filename):
             with open(filename, 'r') as f:
+                if grab:
+                    filterfunc = lambda s: "\n".join(
+                        x for x in s.split("\n")
+                        if not x.startswith("#") and x.strip())
+                else:
+                    filterfunc = lambda x: x
                 if tailbyte:
                     seeksize = max(0, os.stat(filename).st_size - tailbyte)
                     if seeksize:
@@ -854,7 +813,10 @@ def readFile(filename, tailbyte=None, headbyte=None, grab=False):
                 else:
                     return filterfunc(f.read())
     except (OSError, IOError):
-        pass
+        mod, lno = tools.get_traceback_caller(*sys.exc_info())
+        sys.stderr.write("WARNING: file read error, {}({}:{})\n".format(
+            str(e), mod, lno))
+        sys.stderr.flush()
     return ""
 
 
@@ -1670,3 +1632,58 @@ class RealFs(tools.GenericFs):
                     for x in listDirectory(dn, fullPath=True)]
         else:
             return listDirectory(dn, fullPath=False)
+
+def checkDigestFile(digestfile):
+    """Check digest by digestfile"""
+    reEntry = re.compile(r"# (\S+) HASH\n(\S+)  (\S+)", re.S)
+    result = []
+    for alg, hashdata, filename in reEntry.findall(readFile(digestfile)):
+        if hasattr(hashlib, alg.lower()):
+            hashobj = getattr(hashlib, alg.lower())
+            filename = path.join(path.dirname(digestfile), filename)
+            if os.path.exists(filename):
+                with open(filename, 'r') as f:
+                    digest = hashobj(f.read())
+                result.append((alg,
+                               digest.hexdigest().upper() == hashdata.upper()))
+    return result
+
+
+def getRunCommands(not_chroot=False, chroot=None, uid=None, withpid=False):
+    """List run program"""
+
+    def getCmd(procNum):
+        cmdLineFile = '/proc/%s/cmdline' % procNum
+        try:
+            if uid is not None:
+                fstat = os.stat("/proc/%s"%procNum)
+                if fstat.st_uid != uid:
+                    return ""
+            if path.exists(cmdLineFile):
+                if not_chroot:
+                    root_link = '/proc/%s/root' % procNum
+                    if os.readlink(root_link) != "/":
+                        return ""
+                if chroot is not None:
+                    root_link = '/proc/%s/root' % procNum
+                    if os.readlink(root_link) != chroot:
+                        return ""
+                return readFile(cmdLineFile).strip()
+        except Exception:
+            pass
+        return ""
+
+    if not os.access('/proc', os.R_OK):
+        return []
+    if withpid:
+        return filter(lambda x: x[1],
+                      map(lambda x:(x,getCmd(x)),
+                          filter(lambda x: x.isdigit(),
+                                 listDirectory('/proc'))))
+    else:
+        return filter(None,
+                      map(getCmd,
+                          filter(lambda x: x.isdigit(),
+                                 listDirectory('/proc'))))
+
+
