@@ -18,9 +18,9 @@ import sys
 import os
 import re
 from calculate.lib.datavars import ReadonlyVariable
-from calculate.lib.utils.files import readFile, readLinesFile, listDirectory
-from calculate.lib.utils.device import lspci, getUdevDeviceInfo
-from itertools import *
+from calculate.lib.utils.files import readFile, readLinesFile
+import calculate.lib.utils.device as device
+from calculate.lib.utils.device import lspci
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -34,8 +34,8 @@ class VariableHrBoardModel(ReadonlyVariable):
     """
 
     def get(self):
-        model_file = "/sys/class/dmi/id/board_name"
-        return readFile(model_file).strip()
+        return device.sysfs.read(
+            device.sysfs.Path.Dmi, "board_name").strip()
 
 
 class VariableHrBoardVendor(ReadonlyVariable):
@@ -45,8 +45,8 @@ class VariableHrBoardVendor(ReadonlyVariable):
 
     def get(self):
         """Get motherboard vendor"""
-        vendor_file = "/sys/class/dmi/id/board_vendor"
-        return readFile(vendor_file).strip()
+        return device.sysfs.read(
+            device.sysfs.Path.Dmi, "board_vendor").strip()
 
 
 class VariableHrCdromSet(ReadonlyVariable):
@@ -56,12 +56,13 @@ class VariableHrCdromSet(ReadonlyVariable):
     type = "bool"
 
     def get(self):
-        for cdrom in ifilter(lambda x: x.startswith('/sys/block/sr'),
-                             listDirectory('/sys/block', fullPath=True)):
-            if getUdevDeviceInfo(path=cdrom).get('ID_CDROM', '') == "1":
+        cdrom_blocks = (x for x in device.sysfs.listdir(device.sysfs.Path.Block,
+                                                        fullpath=True)
+                        if os.path.basename(x).startswith("sr"))
+        for info in (device.udev.get_device_info(x) for x in cdrom_blocks):
+            if device.udev.is_cdrom(info):
                 return "on"
-        else:
-            return "off"
+        return "off"
 
 
 class VariableHrCpuNum(ReadonlyVariable):
@@ -116,6 +117,46 @@ class VariableHrVirtual(ReadonlyVariable):
         return self.get_lspci() or self.get_cpuinfo() or ""
 
 
+class VariableHrChassisType(ReadonlyVariable):
+    """
+    Тип устройства
+    """
+    # типы взяты из inxi
+    Virtual = "virtual"
+    Unknown = "unknown"
+    Desktop = "desktop"
+    PizzaBox = "pizza-box"
+    Laptop = "laptop"
+    Notebook = "notebook"
+    Portable = "portable"
+    Server = "server"
+    Blade = "blade"
+
+    def get(self):
+        ct = device.sysfs.read(device.sysfs.Path.Dmi,
+                                         "chassis_type").strip()
+        if not ct.isdigit():
+            return self.Unknown
+        ct = int(ct)
+        if ct == 1:
+            return self.Virtual
+        elif ct in (3,4,6,7,13,15,24):
+            return self.Desktop
+        elif ct in (9,10,16):
+            return self.Laptop
+        elif ct == 14:
+            return self.Notebook
+        elif ct in (8, 11):
+            return self.Portable
+        elif ct in (17,23,25):
+            return self.Server
+        elif ct in (27, 28, 29):
+            return self.Blade
+        elif ct == 5:
+            return self.PizzaBox
+        else:
+            return self.Unknown
+
 class VariableHrLaptop(ReadonlyVariable):
     """
     Laptop variable.
@@ -125,11 +166,14 @@ class VariableHrLaptop(ReadonlyVariable):
 
     def get(self):
         """Laptop vendor"""
-        chassis_type = '/sys/class/dmi/id/chassis_type'
-        board_vendor = '/sys/class/dmi/id/board_vendor'
-        notebook_chassis = ['1', '8', '10']
-        if readFile(chassis_type).strip() in notebook_chassis:
-            vendor = (readFile(board_vendor).strip().split(" ")[0]).lower()
+        chassis_type = self.Get('hr_chassis_type')
+        ChassisType = VariableHrChassisType
+        if chassis_type in (ChassisType.Laptop,
+                            ChassisType.Portable,
+                            ChassisType.Notebook):
+            board_vendor = device.sysfs.read(
+                device.sysfs.Path.Dmi, "board_vendor").strip()
+            vendor = (board_vendor.partition(" ")[0]).lower()
             return vendor or "unknown"
         return ""
 
@@ -140,10 +184,9 @@ class VariableHrLaptopModel(ReadonlyVariable):
     """
 
     def get(self):
-        board_name = '/sys/class/dmi/id/board_name'
-        if self.Get('hr_laptop') and os.access(board_name, os.R_OK):
-            val_board_name = readFile(board_name).strip()
-            return val_board_name or "unknown"
+        if self.Get('hr_laptop'):
+            return device.sysfs.read(
+                device.sysfs.Path.Dmi, "board_name").strip() or "unknown"
         return ""
 
 
